package com.ruoyi.mall.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.mall.domain.Vo.ArtVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.mall.mapper.MallArtMapper;
import com.ruoyi.mall.domain.MallArt;
import com.ruoyi.mall.service.IMallArtService;

/**
 * 艺术分类Service业务层处理
 *
 * @author ruoyi
 * @date 2023-11-02
 */
@Service
public class MallArtServiceImpl implements IMallArtService
{
    @Autowired
    private MallArtMapper mallArtMapper;

    /**
     * 查询艺术分类
     *
     * @param artId 艺术分类主键
     * @return 艺术分类
     */
    @Override
    public MallArt selectMallArtByArtId(Long artId)
    {
        return mallArtMapper.selectMallArtByArtId(artId);
    }

    /**
     * 查询艺术分类列表
     *
     * @param mallArt 艺术分类
     * @return 艺术分类
     */
    @Override
    public List<MallArt> selectMallArtList(MallArt mallArt)
    {
        return mallArtMapper.selectMallArtList(mallArt);
    }

    /**
     * 新增艺术分类
     *
     * @param mallArt 艺术分类
     * @return 结果
     */
    @Override
    public int insertMallArt(MallArt mallArt)
    {
        mallArt.setCreateTime(DateUtils.getNowDate());
        return mallArtMapper.insertMallArt(mallArt);
    }

    /**
     * 修改艺术分类
     *
     * @param mallArt 艺术分类
     * @return 结果
     */
    @Override
    public int updateMallArt(MallArt mallArt)
    {
        mallArt.setUpdateTime(DateUtils.getNowDate());
        return mallArtMapper.updateMallArt(mallArt);
    }

    /**
     * 批量删除艺术分类
     *
     * @param artIds 需要删除的艺术分类主键
     * @return 结果
     */
    @Override
    public int deleteMallArtByArtIds(Long[] artIds)
    {
        return mallArtMapper.deleteMallArtByArtIds(artIds);
    }

    /**
     * 删除艺术分类信息
     *
     * @param artId 艺术分类主键
     * @return 结果
     */
    @Override
    public int deleteMallArtByArtId(Long artId)
    {
        return mallArtMapper.deleteMallArtByArtId(artId);
    }

    /**
     * 艺术分类列表
     * @return 结果
     */
    @Override
    public List<ArtVO> selectArtList() {
        return mallArtMapper.selectArtList();
    }
}
